@@ -24,8 +24,8 @@ class Shi7(Tool):
             max_inputs=None,  # note: no limit is set on the # of inputs
             parallel_enabled=False,
             group_paired_ends=True,
-            max_input_bytes_per_file=5 * 1024 * 1024 * 1024,
+            max_input_bytes_per_file=16 * 1024 * 1024 * 1024,
             output_type=OutputType.GZ_TAR,
             output_is_directory=True,
-            output_names=["combined_seqs.fna", "combined_seqs_untrimmed.fna", "shi7.log"],
+            output_names=["combined_seqs.fna", "shi7.log"],
         )
