@@ -30,11 +30,18 @@ class STARInstance(Tool):
             max_inputs=2,
             database_name=database_name,
             database_version=database_version,
-            parallel_enabled=False, # True if parallelize else False
+            parallel_enabled=False,  # True if parallelize else False
             max_input_bytes_per_file=128 * 1024 * 1024 * 1024,
             max_input_bytes_per_file_parallel=4.5 * 1024 * 1024 * 1024,
             output_type=OutputType.SAM_FILE if parallelize else OutputType.GZ_TAR,
             output_is_directory=not parallelize,
+            output_names=[
+                "Aligned.out.sam",
+                "Log.final.out",
+                "Log.out",
+                "Log.progress.out",
+                "SJ.out.tab",
+            ]
         )
 
     def _merge_outputs(self, output_file_paths):
