@@ -21,7 +21,7 @@ from toolchest_client.api.status import ThreadStatus
 from toolchest_client.api.query import Query
 from toolchest_client.files import files_in_path, split_file_by_lines, sanity_check, check_file_size,\
     split_paired_files_by_lines, compress_files_in_path, OutputType
-from toolchest_client.files.s3 import inputs_are_in_s3
+from toolchest_client.files.s3 import inputs_are_in_s3, path_is_s3_uri
 from toolchest_client.tools.tool_args import TOOL_ARG_LISTS, VARIABLE_ARGS
 
 FOUR_POINT_FIVE_GIGABYTES = int(4.5 * 1024 * 1024 * 1024)
@@ -30,7 +30,7 @@ FOUR_POINT_FIVE_GIGABYTES = int(4.5 * 1024 * 1024 * 1024)
 class Tool:
     def __init__(self, tool_name, tool_version, tool_args, output_name,
                  inputs, min_inputs, max_inputs=None, output_path=None,
-                 database_name=None, database_version=None,
+                 database_name=None, database_version=None, custom_database_path=None,
                  input_prefix_mapping=None, parallel_enabled=False,
                  max_input_bytes_per_file=FOUR_POINT_FIVE_GIGABYTES,
                  max_input_bytes_per_file_parallel=FOUR_POINT_FIVE_GIGABYTES,
@@ -58,6 +58,7 @@ class Tool:
         self.max_inputs = max_inputs
         self.database_name = database_name
         self.database_version = database_version
+        self.custom_database_path = custom_database_path
         self.parallel_enabled = parallel_enabled
         self.output_validation_enabled = True
         self.group_paired_ends = group_paired_ends
@@ -76,8 +77,12 @@ class Tool:
     def _prepare_inputs(self):
         """Prepares the input files."""
         if self.compress_inputs:
-            # Input files are all .tar.gz'd together, preserving directory structure
-            self.input_files = [compress_files_in_path(self.inputs)]
+            if path_is_s3_uri(self.inputs):
+                # If the given path is in S3, it is assumed to be compressed already.
+                self.input_files = [self.inputs]
+            else:
+                # Input files are all .tar.gz'd together, preserving directory structure
+                self.input_files = [compress_files_in_path(self.inputs)]
             self.num_input_files = 1
         else:
             # Input files are handled individually, destroying directory structure
@@ -91,6 +96,9 @@ class Tool:
             raise ValueError(f"Too many input files submitted. "
                              f"Maximum is {self.max_inputs}, {self.num_input_files} found.")
 
+    def _is_local_path(self):
+        return self.output_path and not path_is_s3_uri(self.output_path)
+
     def _validate_tool_args(self):
         """
         Validates and sanitizes user-provided custom tool_args.
@@ -120,7 +128,7 @@ class Tool:
         for arg in self.tool_args.split():
             # the minimal_tag for "--arg=a" is "--arg"
             # this allows matching args assigned via an "=" to match on the whitelist
-            minimal_tag = re.sub(r"([^=]+)(=[^\s]+)", rf"\1", arg)
+            minimal_tag = re.sub(r"([^=]+)(=[^\s]+)", r"\1", arg)
             tag_in_whitelist = minimal_tag in whitelist
             if num_args_remaining_after_tag == 0 and tag_in_whitelist:
                 # if the arg is a tag in the whitelist, add it
@@ -185,14 +193,15 @@ class Tool:
 
         if self.inputs is None:
             raise ValueError("No input provided.")
-        if self.output_path and not os.access(
+        if self._is_local_path() and not os.access(
                 os.path.dirname(self.output_path),
                 os.W_OK | os.X_OK,
         ):
             raise OSError("Output file path must be writable.")
         if not self.output_name:
             raise ValueError("Output name must be non-empty.")
-        if self.output_is_directory and self.output_path and not os.path.isdir(self.output_path):
+        if self.output_is_directory and self._is_local_path() \
+                and not os.path.isdir(self.output_path):
             raise ValueError(f"Output path must be a directory. It is currently {self.output_path}")
 
     def _merge_outputs(self, output_file_paths):
@@ -213,7 +222,7 @@ class Tool:
 
         # Check if the given output_path is a directory, if required by the tool
         # and if the user provides output_path.
-        if self.output_path:
+        if self._is_local_path():
             if self.output_is_directory:
                 if os.path.exists(self.output_path):
                     if os.path.isfile(self.output_path):
@@ -227,7 +236,7 @@ class Tool:
 
     def _postflight(self):
         """Generic postflight check. Tools can have more specific implementations."""
-        if self.output_path:
+        if self._is_local_path():
             if self.output_validation_enabled:
                 for output_name in self.output_names:
                     output_file_path = f"{self.output_path}/{output_name}"
@@ -275,7 +284,7 @@ class Tool:
         If two signals are received in a row (e.g. two ctrl-c's), raises an error without killing threads.
         """
         if self.terminating:
-            raise InterruptedError(f"Toolchest client force killed")
+            raise InterruptedError("Toolchest client force killed")
         self.terminating = True
         self._kill_query_threads()
         raise InterruptedError(f"Toolchest client interrupted by signal #{signal_number}")
@@ -301,7 +310,7 @@ class Tool:
             thread_status = self.query_thread_statuses.get(thread_name)
             if not thread.is_alive() and thread_status != ThreadStatus.COMPLETE:
                 self._kill_query_threads()
-                raise ToolchestException(f"A job irrecoverably failed. See logs above for details.")
+                raise ToolchestException("A job irrecoverably failed. See logs above for details.")
 
     def _wait_for_threads_to_finish(self, check_health=True):
         """Waits for all jobs and their corresponding threads to finish while printing their statuses."""
@@ -386,9 +395,10 @@ class Tool:
         temp_input_file_paths = []
         temp_output_file_paths = []
         non_parallel_output_path = f"{self.output_path}/{self.output_name}" if self.output_is_directory \
-            and self.output_path else self.output_path
+            and self._is_local_path() else self.output_path
         for thread_index, input_files in enumerate(jobs):
             # Add split files for merging and later deletion, if running in parallel
+            # TODO: handle parallel output for s3 uri
             temp_parallel_output_file_path = f"{self.output_path}_{thread_index}"
             if should_run_in_parallel:
                 temp_input_file_paths += input_files
@@ -405,6 +415,7 @@ class Tool:
                 "tool_args": self.tool_args,
                 "database_name": self.database_name,
                 "database_version": self.database_version,
+                "custom_database_path": self.custom_database_path,
                 "output_name": f"{thread_index}_{self.output_name}" if should_run_in_parallel else self.output_name,
                 "input_files": input_files,
                 "input_prefix_mapping": self.input_prefix_mapping,
@@ -422,7 +433,7 @@ class Tool:
             new_thread.start()
             time.sleep(5)
 
-        print(f"Finished spawning jobs.")
+        print("Finished spawning jobs.")
 
         self._wait_for_threads_to_finish()
 
